@@ -8,10 +8,12 @@ from django.db import models
 from django.http import Http404
 from rest_framework import status, viewsets
 from rest_framework.exceptions import ValidationError
+from rest_framework.renderers import JSONRenderer
 from rest_framework.response import Response
 from rest_framework.serializers import ListSerializer
 from rest_framework.utils.serializer_helpers import ReturnDict, ReturnList
 
+from dynamicforms.fields import BooleanField
 from .renderers import TemplateHTMLRenderer
 from .settings import DYNAMICFORMS
 
@@ -180,6 +182,18 @@ class ModelViewSet(NewMixin, PutPostMixin, TemplateRendererMixin, viewsets.Model
 
     """
 
+    def paginate_queryset(self, queryset):
+        """
+        Return a single page of results, or `None` if pagination is disabled.
+        """
+        if self.paginator is None:
+            return None
+        # determine request format and handle pagination for json format
+        if isinstance(self.request.accepted_renderer, JSONRenderer) and not BooleanField().to_internal_value(
+                self.request.META.get('HTTP_X_PAGINATION', self.request.GET.get('x_df_pagination', False))):
+            return None
+        return self.paginator.paginate_queryset(queryset, self.request, view=self)
+
     def get_queryset(self):
         """
         Returns records from queryset with filters applied
@@ -262,18 +276,43 @@ class ModelViewSet(NewMixin, PutPostMixin, TemplateRendererMixin, viewsets.Model
         class MyCursorPagination(CursorPagination):
             ordering = ordr
             page_size = ps
+            df_request = None
+
+            def paginate_queryset(self, queryset, request, view=None):
+                self.df_request = request
+                return super().paginate_queryset(queryset, request, view=None)
+
+            def encode_cursor(self, cursor):
+                # Following code is needed when we have https proxy server that redirects requests to http servers.
+                # In that case original code generates cursor links that have http scheme.
+                # So here I check REFERER header to find out which scheme is originally declared.
+                # And use that one in cursor link.
+                request = getattr(self, 'df_request', None)
+                cursor_url = super().encode_cursor(cursor).split(':', 1)
+                req_url = self.df_request.META.get('HTTP_REFERER', None)
+                if req_url:
+                    req_url = req_url.split(':', 1)
+                    if cursor_url[0] != req_url[0] and req_url[0].lower() in ('http', 'https'):
+                        cursor_url[0] = req_url[0]
+                cursor_url = ':'.join(cursor_url)
+                if request and isinstance(request.accepted_renderer, JSONRenderer):
+                    cursor_url += '&x_df_pagination=1'
+                return cursor_url
 
         return MyCursorPagination
 
+    def handle_create_validation_exception(self, e, request, *args, **kwargs):
+        instance = self.new_object()
+        ser = self.get_serializer(instance, data=request.data, partial=False)
+        ser.is_valid(raise_exception=False)
+        e.detail.serializer = ser
+        raise e
+
     def create(self, request, *args, **kwargs):
         try:
             return super().create(request, *args, **kwargs)
         except ValidationError as e:
-            instance = self.new_object()
-            ser = self.get_serializer(instance, data=request.data, partial=False)
-            ser.is_valid(raise_exception=False)
-            e.detail.serializer = ser
-            raise e
+            self.handle_create_validation_exception(e, request, *args, **kwargs)
 
 
 class SingleRecordViewSet(NewMixin, TemplateRendererMixin, viewsets.GenericViewSet):
